package com.steerinfo.dil.service.impl;

import com.steerinfo.dil.mapper.TmstruckReceiptResultMapper;
import com.steerinfo.dil.mapper.TmstruckUnloadResultMapper;
import com.steerinfo.dil.mapper.TmstruckWeightResultMapper;
import com.steerinfo.dil.model.TmstruckReceiptResult;
import com.steerinfo.dil.model.TmstruckUnloadResult;
import com.steerinfo.dil.service.ITmstruckUnloadResultService;
import com.steerinfo.dil.util.DataChange;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;

import java.math.BigDecimal;
import java.text.SimpleDateFormat;
import java.util.Date;
import java.util.List;
import java.util.Map;

/**
 * TmstruckUnloadResult服务实现：
 * @author generator
 * @version 1.0-SNAPSHORT 2021-09-09 07:58
 * 类描述
 * 修订历史：
 * 日期：2021-09-09
 * 作者：generator
 * 参考：
 * 描述：TmstruckUnloadResult服务实现
 * @see null
 * @Copyright 湖南视拓信息技术股份有限公司. All rights reserved.
 */
@Service(value = "tmstruckUnloadResultService")
public class TmstruckUnloadResultServiceImpl implements ITmstruckUnloadResultService {

    @Autowired
    private TmstruckUnloadResultMapper tmstruckUnloadResultMapper;

    @Autowired
    private TmstruckReceiptResultServiceImpl tmstruckReceiptResultService;


    @Autowired
    private UtilsServiceImpl utilsService;

    @Autowired
    private TmstruckMeasureCommissionServiceImpl tmstruckMeasureCommissionService;



    /**
     * 新增卸货实绩
     * 总实绩ID、卸货点
     * @param map
     * @return
     */
    @Override
    public int addUnloadResult(Map<String, Object> map) {
        TmstruckUnloadResult tmstruckUnloadResult = new TmstruckUnloadResult();
        //生成主键ID
        BigDecimal maxId = tmstruckUnloadResultMapper.selectMaxId();
        tmstruckUnloadResult.setId(maxId);
        //插入实绩总表ID
        tmstruckUnloadResult.setResultTotalId(DataChange.dataToBigDecimal(map.get("resultTotalId")));
        //插入卸货点
        tmstruckUnloadResult.setResultUnloadPlaceId(DataChange.dataToBigDecimal(map.get("resultUnloadPlaceId")));
        //新增卸车实绩
        return tmstruckUnloadResultMapper.insertSelective(tmstruckUnloadResult);
    }

    /**
     * 查询所有卸货实绩
     * @param map
     * @return
     */
    @Override
    public List<Map<String, Object>> getUnloadResult(Map<String, Object> map) {
        Integer orderType = (Integer) map.get("orderTypee");
        switch (orderType){
            case 1:

                break;
            case 2:

                break;
            case 3:

                break;
            case 4:

                break;
            case 5:

                break;
            case 6:

                break;
            case 7:

                break;
            case 8:
                return tmstruckUnloadResultMapper.getUnloadResult(map);
            case 9:
                break;
            case 10:

                break;
            case 11:

        }
        return null;
    }


    /**
     * 更新卸货实绩内容 扫码人员扫码后获取信息传输数据给接口
     * 1：销售订单；2：焦炭发运计划；3：水渣发运计划；4：内转到异地库；5：采购辅料订单；6：采购老区燃料订单；
     * 7：采购新区燃料订单；8：采购进口矿(万州-厂内)；9：采购内转(达州-厂内)；10：采购内转(老区-厂内)； 11：厂内内转
     * @param map
     * @return
     */
    @Override
    @Transactional
    public int updateUnloadResult(Map<String, Object> map) {
        int i = 0;
        map.putAll(tmstruckUnloadResultMapper.selectTotalIdByOrderNo((String) map.get("orderNumber")));
        BigDecimal orderType = DataChange.dataToBigDecimal(map.get("orderTypee"));
        switch (orderType.intValue()){
            case 1:
                break;
            case 2:
                break;
            case 3:
                break;
            case 4:
                break;
            case 5:
            case 6:
            case 7:
            case 8:
                i += updateUnloadResultBy(map); //更新卸货实绩
                i += tmstruckMeasureCommissionService.addPiMeasureCommission(map); //卸货完成后新增一条计皮委托 并发送计皮委托
                i += tmstruckReceiptResultService.addReceiptResult(map); //新增完卸车实绩后新增一条收货实绩
                i += utilsService.updateOrderLineSequence(map, 4);//修改路段顺序号 4：计皮
                break;
            case 9:
                break;
            case 10:
                break;
            case 11:

        }
        return i;
    }

    /**
     * 扫码确认卸货 更新卸货实绩
     *  运输订单号
     *  卸货时间
     *  卸货地点
     * @param map
     * @return
     */
    public int updateUnloadResultBy(Map<String, Object> map){
        TmstruckUnloadResult tmstruckUnloadResult = new TmstruckUnloadResult();
        tmstruckUnloadResult.setResultId(DataChange.dataToBigDecimal(map.get("resultId")));
        //通过卸货地点（仓库）查询仓库ID
        BigDecimal resultUnloadPlaceId = tmstruckUnloadResultMapper.getWarehouseIdByWName((String) map.get("warehouseName"));
        // 修改卸货点
        if(resultUnloadPlaceId != null){
            tmstruckUnloadResult.setResultUnloadPlaceId(resultUnloadPlaceId);
        }
        //获得卸货时间
        tmstruckUnloadResult.setResultStartTime(new Date((long) map.get("unloadTime")));
        //扫码后确认卸货所以卸货状态码为  1 同意
        tmstruckUnloadResult.setUnloadStatus(new BigDecimal(1));
        tmstruckUnloadResult.setInsertTime(new Date());
        tmstruckUnloadResult.setInsertUsername("admin");
        //新增卸车实绩内容
        return tmstruckUnloadResultMapper.updateByPrimaryKeySelective(tmstruckUnloadResult);
    }

}
